@@ -5,13 +5,13 @@ _geomesa-cassandra(){
   prev="${COMP_WORDS[COMP_CWORD-1]}";
 
   if [[ "${COMP_WORDS[1]}" == "help" ]]; then
-    COMPREPLY=( $(compgen -W "get-type-names describe-schema help env version get-sft-config create-schema remove-schema delete-features ingest export explain configure classpath scala-console" ${cur}));
+    COMPREPLY=( $(compgen -W "get-type-names describe-schema help env version get-sft-config create-schema remove-schema delete-features ingest export playback explain configure classpath scala-console" ${cur}));
     return 0;
   fi;
 
   case ${COMP_CWORD} in
     1)
-      COMPREPLY=( $(compgen -W "get-type-names describe-schema help env version get-sft-config create-schema remove-schema delete-features ingest export explain configure classpath scala-console" ${cur}));
+      COMPREPLY=( $(compgen -W "get-type-names describe-schema help env version get-sft-config create-schema remove-schema delete-features ingest export playback explain configure classpath scala-console" ${cur}));
       ;;
     [2-9] | [1-9][0-9])
       if [[ "${cur}" =~ ^-[a-zA-Z-]?+$ ]]; then
@@ -53,12 +53,16 @@ _geomesa-cassandra(){
               return 0;
               ;;
                   ingest)
-              COMPREPLY=( $(compgen -W "--user --password --run-mode --catalog --converter --threads --feature-name --contact-point --input-format --key-space --spec" -- ${cur}));
+              COMPREPLY=( $(compgen -W "--run-mode --catalog --threads --no-tracking --force --src-list --feature-name --contact-point --user --password --converter --split-max-size --input-format --key-space --spec" -- ${cur}));
               return 0;
               ;;
                   export)
               COMPREPLY=( $(compgen -W "--max-features --catalog --user --gzip --feature-name --contact-point --output --index --cql --key-space --hints --attributes --output-format --no-header --password" -- ${cur}));
               return 0;
+              ;;
+                  playback)
+              COMPREPLY=( $(compgen -W "--user --attributes --password --interval --no-header --catalog --output --max-features --gzip --step-window --dtg --key-space --cql --hints --output-format --contact-point --rate --feature-name" -- ${cur}));
+              return 0;
               ;;
                   explain)
               COMPREPLY=( $(compgen -W "--hints --key-space --user --contact-point --cql --feature-name --index --attributes --password --catalog" -- ${cur}));
